@@ -150,11 +150,12 @@ class Bulkapi:
         del self.header["Content-Type"]
         self._createdFiles = []
 
-    def validation(self, file: IO = None, **kwargs):
+    def validation(self, file: IO = None,encoding:str='utf-8', **kwargs):
         """
         Send the file to a validation endpoint. Return the response object from requests.
         Argument:
             file : REQUIRED : File in a string of byte format.
+            encoding : OPTIONAL : type of encoding used for the file.
         Possible kwargs:
             compress_level : handle the compression level, from 0 (no compression) to 9 (slow but more compressed). default 5.
         """
@@ -163,9 +164,9 @@ class Bulkapi:
             raise Exception("Expecting a file")
         path = "/aa/collect/v1/events/validate"
         if file.endswith(".gz") == False:
-            with open(file, "r") as f:
+            with open(file, "r",encoding=encoding) as f:
                 content = f.read()
-            data = gzip.compress(content.encode("utf-8"),
+            data = gzip.compress(content.encode('utf-8'),
                                  compresslevel=compress_level)
             filename = f"{file}.gz"
         elif file.endswith(".gz"):
@@ -196,7 +197,7 @@ class Bulkapi:
         if returnDF:
             return df
 
-    def _checkFiles(self, file: str = None):
+    def _checkFiles(self, file: str = None,encoding:str = "utf-8"):
         """
         Internal method that check content and format of the file
         """
@@ -205,22 +206,23 @@ class Bulkapi:
         else:  # if sending not gzipped file.
             new_folder = Path('tmp/')
             new_folder.mkdir(exist_ok=True)
-            with open(file, "rb") as f:
+            with open(file, "r",encoding=encoding) as f:
                 content = f.read()
                 new_path = new_folder / f"{file}.gz"
                 with gzip.open(Path(new_path), 'wb') as f:
-                    f.write(content)
+                    f.write(content.encode('utf-8'))
                 # save the filename to delete
                 self._createdFiles.append(new_path)
             return new_path
 
-    def sendFiles(self, files: Union[list, IO] = None, **kwargs):
+    def sendFiles(self, files: Union[list, IO] = None,encoding:str='utf-8',**kwargs):
         """
         Method to send the file(s) through the Bulk API. Returns a list with the different status file sent.
         Arguments:
             files : REQUIRED : file to be send to the aalytics collection server. It can be a list or the name of the file to be send.
-            If list is being send, we assume that each file are to be sent in different visitor groups.
-            If file are not gzipped, we will compress the file and saved it as gz in the folder.
+                If list is being send, we assume that each file are to be sent in different visitor groups.
+                If file are not gzipped, we will compress the file and saved it as gz in the folder.
+            encoding : OPTIONAL : if encoding is different that default utf-8.
         possible kwargs:
             workers : maximum amount of worker for parallele processing. (default 4)
         """
@@ -231,10 +233,10 @@ class Bulkapi:
         files_gz = list()
         if type(files) == list:
             for file in files:
-                fileName = self._checkFiles(file)
+                fileName = self._checkFiles(file,encoding=encoding)
                 files_gz.append(fileName)
         elif type(files) == str:
-            fileName = self._checkFiles(files)
+            fileName = self._checkFiles(files,encoding=encoding)
             files_gz.append(fileName)
         vgid_headers = [f"ingestion_{x}" for x in range(len(files_gz))]
         list_headers = [{**self.header, 'x-adobe-vgid': vgid}
